#!/bin/sh
#
# Mac OS-X compile script for GNAT2015
# ...this script should work on any recent
# standard configuration of OS-X so long as
# the 2015 GNU Ada compiler, gnatmake, is installed.
# However, if OS-X is older than v10.4, the user will need
# to install OpenAL.
#
# important note:
# on linux, gcc requires libstdc++ but here on OSX,
# gcc == clang++, which requires libc++
#
#=====================================================
# this script requires special prep of the frameworks
# using a "fixlibs.sh" renaming script.
#=====================================================

# use this to ensure a complete recompilation:
if [ -d ./obj/ ]; then
	rm ./obj/*
else
	mkdir obj
fi


# prepare libsnd4ada.so file prior to gnatmake

g++ snd4ada.cpp -c -Werror -fPIC -I./incLocal

g++ -shared -o ./libs/osx/libsnd4ada.so snd4ada.o \
-F$PWD/adagate.app/Contents/Frameworks/ \
-framework sfml-audio -framework sfml-system

##################################################

gnatmake  adagate -O3  \
-o adagate_osx \
--subdirs=./obj \
-I$PWD/adabindings/gl \
-I$PWD/adabindings/sdlada \
-I$PWD/adabindings/AdaPngLib \
-largs -lm -lz \
-lc++ \
$PWD/libs/osx/libsnd4ada.so \
$PWD/libs/osx/libSDL2.a \
$PWD/libs/osx/libiconv.a \
\
-F$PWD/adagate.app/Contents/Frameworks/ \
-framework sfml-audio -framework sfml-system \
-framework FLAC -framework ogg \
-framework vorbis -framework vorbisenc -framework vorbisfile \
\
-framework OpenGL \
-framework ForceFeedback \
-framework CoreFoundation \
-framework Carbon \
-framework Cocoa \
-framework QuartzCore \
-framework IOKit \
-framework CoreAudio \
-framework AudioUnit \
-framework OpenAL \
-pthread

cp ./obj/adagate_osx .


# SFML v2.3.2 needs extralibs: FLAC, ogg, vorbis*

# -- Copyright (C) 2016  <fastrgv@gmail.com>
# --
# -- This program is free software: you can redistribute it and/or modify
# -- it under the terms of the GNU General Public License as published by
# -- the Free Software Foundation, either version 3 of the License, or
# -- (at your option) any later version.
# --
# -- This program is distributed in the hope that it will be useful,
# -- but WITHOUT ANY WARRANTY; without even the implied warranty of
# -- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# -- GNU General Public License for more details.
# --
# -- You may read the full text of the GNU General Public License
# -- at <http://www.gnu.org/licenses/>.

